@@ -37,11 +37,12 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
 
     MAX_DISPLAY = 24*60*60
 
-    def __init__(self, feed):
+    def __init__(self, mercury):
         super(self.__class__, self).__init__()
         uic.loadUi(MAIN_UI_PATH, self)
 
-        self.feed = feed
+        self.mercury = mercury
+        self.feed = MercuryFeed(mercury)
 
         # sent Title font size relative to the system's default size
         scaling = 1.8
@@ -52,7 +53,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
         self.labelTitle.setFont(font)
 
         # create popup Widgets
-        self.connectionDialog = ConnectionDialog(self, feed.mercury, CONF)
+        self.connectionDialog = ConnectionDialog(self, self.mercury, CONF)
         self.readingsDialog = None
         self.modulesDialog = None
 
@@ -67,7 +68,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
         w = self.canvas.y_axis_width
         self.gridLayoutTop.setContentsMargins(w, 0, w, 0)
         self.gridLayoutBottom.setContentsMargins(w, 0, w, 0)
-        self.horizontalSlider.setMaximum(int(self.feed.refresh*self.MAX_DISPLAY/60))
+        self.horizontalSlider.setMaximum(self.MAX_DISPLAY/60)
 
         # connect slider to plot
         self.horizontalSlider.valueChanged.connect(self.on_slider_changed)
@@ -93,16 +94,15 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
 
         # check if mercury is connected, connect slots
         self.display_message('Looking for temperature controller at %s...' %
-                             self.feed.visa_address)
-        if self.feed.mercury.connected:
-            self.update_gui_connection(connected=True)
+                             self.mercury.visa_address)
+        self.update_gui_connection(self.mercury.connected)
 
         # start (stop) updates of GUI when mercury is connected (disconnected)
         # adjust clickable buttons upon connect / disconnect
         self.feed.connected_signal.connect(self.update_gui_connection)
 
         # get new readings every second, update UI
-        self.feed.new_readings_signal.connect(self.update_text)
+        self.feed.new_readings_signal.connect(self.update_controls)
         self.feed.new_readings_signal.connect(self.update_plot)
 
         # set up logging to file
@@ -212,27 +212,40 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
         self.statusbar.showMessage('%s' % text)
 
     @QtCore.pyqtSlot(object)
-    def update_text(self, readings):
+    def update_controls(self, readings):
         """
         Parses readings for the MercuryMonitorApp and updates UI accordingly
         """
+
         # heater signals
         self.h1_label.setText('Heater, %s V:' % readings['HeaterVolt'])
         self.h1_edit.updateValue(readings['HeaterPercent'])
 
-        is_heater_auto = readings['HeaterAuto'] == 'ON'
-        self.h1_edit.setReadOnly(is_heater_auto)
-        self.h1_edit.setEnabled(not is_heater_auto)
-        self.h2_checkbox.setChecked(is_heater_auto)
+        if self.feed.heater:
+            is_heater_auto = readings['HeaterAuto'] == 'ON'
+            self.h1_edit.setReadOnly(is_heater_auto)
+            self.h1_edit.setEnabled(not is_heater_auto)
+            self.h2_checkbox.setChecked(is_heater_auto)
+            self.h2_checkbox.setEnabled(True)
+        else:
+            self.h1_edit.setReadOnly(True)
+            self.h1_edit.setEnabled(False)
+            self.h2_checkbox.setEnabled(False)
 
         # gas flow signals
         self.gf1_edit.updateValue(readings['FlowPercent'])
         self.gf1_label.setText('Gas flow (min = %s%%):' % readings['FlowMin'])
 
-        is_gf_auto = readings['FlowAuto'] == 'ON'
-        self.gf2_checkbox.setChecked(is_gf_auto)
-        self.gf1_edit.setEnabled(not is_gf_auto)
-        self.gf1_edit.setReadOnly(is_gf_auto)
+        if self.feed.gasflow:
+            is_gf_auto = readings['FlowAuto'] == 'ON'
+            self.gf1_edit.setReadOnly(is_gf_auto)
+            self.gf1_edit.setEnabled(not is_gf_auto)
+            self.gf2_checkbox.setChecked(is_gf_auto)
+            self.gf2_checkbox.setEnabled(True)
+        else:
+            self.gf1_edit.setEnabled(True)
+            self.gf1_edit.setEnabled(False)
+            self.gf2_checkbox.setEnabled(False)
 
         # temperature signals
         self.t1_reading.setText('%s K' % round(readings['Temp'], 3))
@@ -325,7 +338,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
 
     def log_temperature_data(self):
         # save temperature data to log file
-        if self.feed.mercury.connected:
+        if self.mercury.connected:
             self.save_temperature_data(self.log_file)
 
 # =================== CALLBACKS FOR SETTING CHANGES ===========================
@@ -397,7 +410,7 @@ class MercuryMonitorApp(QtWidgets.QMainWindow):
     def on_readings_clicked(self):
         # create readings overview window if not present
         if self.readingsDialog is None:
-            self.readingsDialog = ReadingsOverview(self.feed.mercury)
+            self.readingsDialog = ReadingsOverview(self.mercury)
         # show it
         self.readingsDialog.show()
 
@@ -598,9 +611,8 @@ def run():
     visa_library = CONF.get('Connection', 'VISA_LIBRARY')
 
     mercury = MercuryITC(mercury_address, visa_library, open_timeout=1)
-    feed = MercuryFeed(mercury)
 
-    mercury_gui = MercuryMonitorApp(feed)
+    mercury_gui = MercuryMonitorApp(mercury)
     mercury_gui.show()
 
     app.exec_()
